% Parameters
desiredTemperature = 25; % Setpoint temperature
initialTemperature = 20; % Initial temperature
time = 0:0.1:10; % Time vector

% Simulate the dynamic system (e.g., a first-order system)
tau = 5; % Time constant
sys = tf(1, [tau, 1]); % Transfer function of the system
temperatureResponse = initialTemperature + step(sys, time);

% PID Controller Parameters
Kp = 1; % Proportional gain
Ki = 0.1; % Integral gain
Kd = 0.01; % Derivative gain

% PID Controller Design
controller = pid(Kp, Ki, Kd);
sysWithController = feedback(sys * controller, 1);

% Simulate the closed-loop system
temperatureWithController = initialTemperature + step(sysWithController, time);

% Plot the results
figure;

subplot(2,1,1);
plot(time, temperatureResponse, 'b', 'LineWidth', 2);
title('Temperature Response without Controller');
xlabel('Time');
ylabel('Temperature');
grid on;

subplot(2,1,2);
plot(time, temperatureWithController, 'r', 'LineWidth', 2);
title('Temperature Response with PID Controller');
xlabel('Time');
ylabel('Temperature');
grid on;

% Display the final temperature
finalTemperature = temperatureWithController(end);
disp(['Final Temperature: ', num2str(finalTemperature)]);
